summaryrefslogtreecommitdiffstats
path: root/java/src/hdf/hdf5lib/exceptions
diff options
context:
space:
mode:
authorDana Robinson <43805+derobins@users.noreply.github.com>2020-11-30 12:50:39 (GMT)
committerGitHub <noreply@github.com>2020-11-30 12:50:39 (GMT)
commitc256612e0950f3389249aa3a151d66ce01704d89 (patch)
tree2b87801fba6d5d7beef06588a6631b764594183b /java/src/hdf/hdf5lib/exceptions
parenta6e3d226043eb81aac3c315c6fd9262a036f9f1d (diff)
downloadhdf5-c256612e0950f3389249aa3a151d66ce01704d89.zip
hdf5-c256612e0950f3389249aa3a151d66ce01704d89.tar.gz
hdf5-c256612e0950f3389249aa3a151d66ce01704d89.tar.bz2
Replace H5E_ATOM major error category with H5E_ID (#121)
* Renames H5I_ATOM to H5I_ID, among other related changes * Java has been updated. * Fortran is failing on my VM, even though I don't touch that. * Adds a RELEASE.txt note for H5E_ATOM to H5E_ID changes * Fixes typos in comments
Diffstat (limited to 'java/src/hdf/hdf5lib/exceptions')
-rw-r--r--java/src/hdf/hdf5lib/exceptions/HDF5IdException.java (renamed from java/src/hdf/hdf5lib/exceptions/HDF5AtomException.java)12
-rw-r--r--java/src/hdf/hdf5lib/exceptions/HDF5LibraryException.java6
2 files changed, 9 insertions, 9 deletions
diff --git a/java/src/hdf/hdf5lib/exceptions/HDF5LibraryException.java b/java/src/hdf/hdf5lib/exceptions/HDF5LibraryException.java
index 54acbdd..9bd43e8 100644
--- a/java/src/hdf/hdf5lib/exceptions/HDF5LibraryException.java
+++ b/java/src/hdf/hdf5lib/exceptions/HDF5LibraryException.java
@@ -201,14 +201,14 @@ public class HDF5LibraryException extends HDF5Exception {
else if (err_code == HDF5Constants.H5E_CANTRELEASE) {
return "Can't release object";
}
- else if (err_code == HDF5Constants.H5E_BADATOM) {
- return "Can't find atom information";
+ else if (err_code == HDF5Constants.H5E_BADID) {
+ return "Can't find ID information";
}
else if (err_code == HDF5Constants.H5E_BADGROUP) {
return "Can't find group information";
}
else if (err_code == HDF5Constants.H5E_CANTREGISTER) {
- return "Can't register new atom";
+ return "Can't register new ID";
}
else if (err_code == HDF5Constants.H5E_CANTINC) {
return "Can't increment reference count";
diff --git a/java/src/hdf/hdf5lib/exceptions/HDF5AtomException.java b/java/src/hdf/hdf5lib/exceptions/HDF5IdException.java
index 850044c..37f0956 100644
--- a/java/src/hdf/hdf5lib/exceptions/HDF5AtomException.java
+++ b/java/src/hdf/hdf5lib/exceptions/HDF5IdException.java
@@ -16,26 +16,26 @@ package hdf.hdf5lib.exceptions;
/**
* The class HDF5LibraryException returns errors raised by the HDF5 library.
* <p>
- * This sub-class represents HDF-5 major error code <b>H5E_ATOM</b>
+ * This sub-class represents HDF-5 major error code <b>H5E_ID</b>
*/
-public class HDF5AtomException extends HDF5LibraryException {
+public class HDF5IdException extends HDF5LibraryException {
/**
* Constructs an <code>HDF5AtomException</code> with no specified detail
* message.
*/
- public HDF5AtomException() {
+ public HDF5IdException() {
super();
}
/**
* Constructs an <code>HDF5AtomException</code> with the specified detail
* message.
*
* @param s
* the detail message.
*/
- public HDF5AtomException(String s) {
+ public HDF5IdException(String s) {
super(s);
}
@@ -16,26 +16,26 @@ package hdf.hdf5lib.exceptions;
/**
- * Constructs an <code>HDF5AtomException</code> with no specified detail
+ * Constructs an <code>HDF5IdException</code> with no specified detail
* message.
*/
@@ -16,26 +16,26 @@ package hdf.hdf5lib.exceptions;
}
/**
- * Constructs an <code>HDF5AtomException</code> with the specified detail
+ * Constructs an <code>HDF5IdException</code> with the specified detail
* message.
*